@@ -1,15 +1,15 @@
-var B = require('../').Buffer
-var test = require('tape')
+const B = require('../').Buffer
+const test = require('tape')
 
 test('instanceof Buffer', function (t) {
-  var buf = new B([1, 2])
+  const buf = new B([1, 2])
   t.ok(buf instanceof B)
   t.end()
 })
 
 test('convert to Uint8Array in modern browsers', function (t) {
-  var buf = new B([1, 2])
-  var uint8array = new Uint8Array(buf.buffer)
+  const buf = new B([1, 2])
+  const uint8array = new Uint8Array(buf.buffer)
   t.ok(uint8array instanceof Uint8Array)
   t.equal(uint8array[0], 1)
   t.equal(uint8array[1], 2)
@@ -17,7 +17,7 @@ test('convert to Uint8Array in modern browsers', function (t) {
 })
 
 test('indexes from a string', function (t) {
-  var buf = new B('abc')
+  const buf = new B('abc')
   t.equal(buf[0], 97)
   t.equal(buf[1], 98)
   t.equal(buf[2], 99)
@@ -25,7 +25,7 @@ test('indexes from a string', function (t) {
 })
 
 test('indexes from an array', function (t) {
-  var buf = new B([97, 98, 99])
+  const buf = new B([97, 98, 99])
   t.equal(buf[0], 97)
   t.equal(buf[1], 98)
   t.equal(buf[2], 99)
@@ -33,7 +33,7 @@ test('indexes from an array', function (t) {
 })
 
 test('setting index value should modify buffer contents', function (t) {
-  var buf = new B([97, 98, 99])
+  const buf = new B([97, 98, 99])
   t.equal(buf[2], 99)
   t.equal(buf.toString(), 'abc')
 
@@ -44,7 +44,7 @@ test('setting index value should modify buffer contents', function (t) {
 })
 
 test('storing negative number should cast to unsigned', function (t) {
-  var buf = new B(1)
+  let buf = new B(1)
 
   buf[0] = -3
   t.equal(buf[0], 253)
@@ -57,8 +57,8 @@ test('storing negative number should cast to unsigned', function (t) {
 })
 
 test('test that memory is copied from array-like', function (t) {
-  var u = new Uint8Array(4)
-  var b = new B(u)
+  const u = new Uint8Array(4)
+  const b = new B(u)
   b[0] = 1
   b[1] = 2
   b[2] = 3
