@@ -1,10 +1,10 @@
-var B = require('../').Buffer
-var test = require('tape')
+const B = require('../').Buffer
+const test = require('tape')
 
 test('buffer.compare', function (t) {
-  var b = new B(1).fill('a')
-  var c = new B(1).fill('c')
-  var d = new B(2).fill('aa')
+  const b = new B(1).fill('a')
+  const c = new B(1).fill('c')
+  const d = new B(2).fill('aa')
 
   t.equal(b.compare(c), -1)
   t.equal(c.compare(d), 1)
@@ -21,27 +21,27 @@ test('buffer.compare', function (t) {
 
 test('buffer.compare argument validation', function (t) {
   t.throws(function () {
-    var b = new B(1)
+    const b = new B(1)
     B.compare(b, 'abc')
   })
 
   t.throws(function () {
-    var b = new B(1)
+    const b = new B(1)
     B.compare('abc', b)
   })
 
   t.throws(function () {
-    var b = new B(1)
+    const b = new B(1)
     b.compare('abc')
   })
   t.end()
 })
 
 test('buffer.equals', function (t) {
-  var b = new B(5).fill('abcdf')
-  var c = new B(5).fill('abcdf')
-  var d = new B(5).fill('abcde')
-  var e = new B(6).fill('abcdef')
+  const b = new B(5).fill('abcdf')
+  const c = new B(5).fill('abcdf')
+  const d = new B(5).fill('abcde')
+  const e = new B(6).fill('abcdef')
 
   t.ok(b.equals(c))
   t.ok(!c.equals(d))
@@ -51,7 +51,7 @@ test('buffer.equals', function (t) {
 
 test('buffer.equals argument validation', function (t) {
   t.throws(function () {
-    var b = new B(1)
+    const b = new B(1)
     b.equals('abc')
   })
   t.end()
